@@ -4,12 +4,15 @@ use namespace::autoclean;
 
 extends qw(MooseX::App::Cmd::Command);
 
-use XML::Toolkit::Builder;
+use XML::Toolkit::Config::Container;
 use MooseX::Types::Path::Class qw(File);
 use Moose::Util::TypeConstraints;
 
 with qw(MooseX::Getopt::Dashes);
-with qw(XML::Toolkit::Cmd::ClassTemplate);
+with qw(
+  XML::Toolkit::Cmd::ClassTemplate
+  XML::Toolkit::Builder::NamespaceRegistry
+);
 
 has input => (
     isa      => File,
@@ -18,54 +21,6 @@ has input => (
     required => 1,
 );
 
-has namespace => (
-    isa        => 'Str',
-    is         => 'ro',
-    lazy_build => 1,
-);
-
-sub _build_namespace { 'MyApp' }
-
-has xmlns => (
-    isa     => 'HashRef',
-    is      => 'ro',
-    lazy    => 1,
-    default => sub { {} },
-);
-
-has filter_class => (
-    isa        => 'Str',
-    is         => 'ro',
-    lazy_build => 1,
-);
-
-sub _build_filter_class { 'XML::Toolkit::Builder::FilterNS' }
-
-has _builder => (
-    reader     => 'builder',
-    isa        => 'XML::Toolkit::Builder',
-    is         => 'ro',
-    lazy_build => 1,
-    handles    => [qw(build_class)],
-);
-
-sub _build__builder {
-    my ($self) = @_;
-
-    return XML::Toolkit::Builder->new(
-        namespace     => $self->namespace,
-        template      => $self->template,
-        filter_class  => $self->filter_class,
-        namespace_map => $self->xmlns,
-    );
-}
-
-sub run {
-    my ($self) = @_;
-    $self->builder->parse_file( $self->input->stringify );
-    print $self->builder->render;
-}
-
 around _build_template => sub {
     my ( $next, $self ) = ( shift, shift );
     my $template = <<'END_TEMPLATE';
@@ -84,6 +39,18 @@ END_TEMPLATE
     return $template;
 };
 
+sub run {
+    my ($self) = @_;
+    my $builder = XML::Toolkit::Config::Container->new(
+        namespace     => $self->namespace,
+        namespace_map => $self->xmlns,
+        template      => $self->template,
+    )->builder;
+
+    $builder->parse_file( $self->input->stringify );
+    print $builder->render;
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 __END__
